@@ -6,6 +6,7 @@ from ip import Ip
 from osm import Osm
 from bing import Bing
 from nokia import Nokia
+from yahoo import Yahoo
 from tomtom import Tomtom
 from google import Google
 from arcgis import Arcgis
@@ -18,6 +19,54 @@ from geolytica import Geolytica
 from canadapost import Canadapost
 
 
+def yahoo(location):
+    """
+    # Yahoo
+
+    Yahoo PlaceFinder is a geocoding Web service that helps developers make
+    their applications location-aware by converting street addresses or
+    place names into geographic coordinates (and vice versa).
+    Using Geocoder you can retrieve Yahoo's geocoded data from Yahoo BOSS Geo Services.
+
+    ## Python Example
+
+        >>> import geocoder # pip install geocoder
+        >>> g = geocoder.yahoo('<address>')
+        >>> g.lat, g.lng
+        45.413140 -75.656703
+        ...
+
+    ## Geocoder Attributes
+
+        * address
+        * country
+        * county
+        * lat
+        * lng
+        * locality
+        * location
+        * neighborhood
+        * postal
+        * provider
+        * quality
+        * route
+        * state
+        * status
+        * street_number
+
+    ## Parameters
+
+        * :param ``location``: Your search location you want geocoded.
+
+    ## References
+
+        * [GitHub Repo](https://github.com/DenisCarriere/geocoder)
+        * [GitHub Wiki](https://github.com/DenisCarriere/geocoder/wiki)
+        * [Yahoo BOSS Geo Services](https://developer.yahoo.com/boss/geo/)
+
+    """
+    return Yahoo(location)
+
 def geolytica(location):
     """
     # Geolytica
