@@ -8,20 +8,22 @@ class Arcgis(Base):
     api = 'ArcGIS REST API'
     url = 'http://geocode.arcgis.com/arcgis/rest/'
     url += 'services/World/GeocodeServer/find'
-    api_references = ['[{0}](https://developers.arcgis.com/rest/geocode/api-reference/geocoding-find.htm)'.format(api)]
-    description = 'The World Geocoding Service finds addresses and places in all supported countries\n'
-    description += 'from a single endpoint. The service can find point locations of addresses,\n'
-    description += 'business names, and so on.  The output points can be visualized on a map,\n'
-    description += 'inserted as stops for a route, or loaded as input for a spatial analysis.\n'
-    description += 'an address, retrieving imagery metadata, or creating a route.'
+    _api_reference = ['[{0}](https://developers.arcgis.com/rest/geocode/api-reference/geocoding-find.htm)'.format(api)]
+    _description = 'The World Geocoding Service finds addresses and places in all supported countries\n'
+    _description += 'from a single endpoint. The service can find point locations of addresses,\n'
+    _description += 'business names, and so on.  The output points can be visualized on a map,\n'
+    _description += 'inserted as stops for a route, or loaded as input for a spatial analysis.\n'
+    _description += 'an address, retrieving imagery metadata, or creating a route.'
+    _api_parameter = []
 
     def __init__(self, location):
         self.location = location
         self.json = dict()
+        self.parse = dict()
         self.params = dict()
         self.params['text'] = location
         self.params['maxLocations'] = 1
-        self.params['f'] = 'pjson'
+        self.params['f'] = 'json'
 
         # Initialize
         self._connect()
@@ -69,5 +71,6 @@ class Arcgis(Base):
 
 
 if __name__ == '__main__':
-    g = Arcgis('Ottawa, ON')
+    g = Arcgis('453 Booth, Ottawa, ON')
+    g.help()
     g.debug()
\ No newline at end of file
